@@ -39,7 +39,7 @@ we pass it to the functions. At the end of the preprocess we expand the image
 back to rank 4.
 """
 
-import tensorflow.compat.v2 as tf
+import tensorflow as tf
 
 import numpy as np
 
